/*****************************************************************************
 *
 * File:  PV2_3.ddl
 * Version: 2.3.0
 * Date: 01/14/2022
 *
 *****************************************************************************
 * Copyright (c) 2016-2022, FieldComm Group, All Rights Reserved
 *****************************************************************************
 *
 * Description: Defines the standard collections used by DDs that support
 *      more than one analog channel
 *
 *****************************************************************************
 */

/*****************************************************************************
 * The manufacturer line
 *****************************************************************************
 */
MANUFACTURER STANDARD, DEVICE_TYPE _PV, DEVICE_REVISION 2, DD_REVISION 3


/*****************************************************************************
 * Include Files
 *****************************************************************************
 */
#include "macros2.h"
#include "embedded_strings.h"
#include "methods.h"

/*****************************************************************************
 * Definitions (#define, typedef, enum)
 *****************************************************************************
 */
#ifdef _PDM_
IMPORT "PV1_3.ddl"
#else
IMPORT STANDARD _PV, DEVICE_REVISION 1, DD_REVISION 3
#endif
{
    EVERYTHING;

    REDEFINITIONS
    {
        /* TOKENIZER v8.2.20 seems to have a bug where ADDing members to a collection
           cause the collection to ONLY have those added members (the originals get
           forgotten). Tokenizer v10.44 works as expected.  Commented code below
           will not work in v8 tokenizer.  The work-around for now is to redefine the
           entire collection rather than just adding new members. */
        //COLLECTION OF COLLECTION secondary_variable
        //{
        //    MEMBERS
        //    {
        //        ADD RANGING,         SVscaling;
        //        ADD DAQ,             SVanalog_io;
        //    }
        //}

        COLLECTION OF COLLECTION secondary_variable
        {
            REDEFINE MEMBERS
            {
                //Original members
                DEVICE_VARIABLE,        deviceVariables[secondary_variable_code];

                //New members to be added
                RANGING,         SVscaling;
                DAQ,             SVanalog_io;
            }
        }

        COLLECTION OF COLLECTION tertiary_variable
        {
            REDEFINE MEMBERS
            {
                //Original members
                DEVICE_VARIABLE,        deviceVariables[tertiary_variable_code];

                //New members to be added
                RANGING,         TVscaling;
                DAQ,             TVanalog_io;
            }
        }

        COLLECTION OF COLLECTION quaternary_variable
        {
            REDEFINE MEMBERS
            {
                //Original members
                DEVICE_VARIABLE,        deviceVariables[quaternary_variable_code];

                //New members to be added
                RANGING,         QVscaling;
                DAQ,             QVanalog_io;
            }
        }

        COLLECTION OF VARIABLE analog_io
        {
            REDEFINE MEMBERS
            {
                //Original members
//Remove new dictionary references from legacy binary format
                ANALOG_VALUE,           loopCurrent,        Loop_Current_temp,         loop_current_help_temp;
//Remove new dictionary references from legacy binary format
                ALARM_CODE,             loop_alarm_code,    loop_alarm_code_temp,      loop_alarm_code_help_temp;
//Remove new dictionary references from legacy binary format
                ANALOG_CHANNEL_FLAGS,   loop_flags,         loop_flags_temp,           loop_flags_help_temp;

                //New members to be added
//Remove new dictionary references from legacy binary format
                ANALOG_UNITS,           PVloopUnits,                loop_current_unit_temp,           loop_current_unit_help_temp;
//Remove new dictionary references from legacy binary format
                ANALOG_DAMPING,         PVloopDamping,              loop_current_damping_temp,        loop_current_damping_help_temp;
//Remove new dictionary references from legacy binary format
                UPPER_ENDPOINT_VALUE,   PVloopCurrentUpperEndPoint, loop_current_upper_endpoint_temp, loop_current_upper_endpoint_help_temp;
//Remove new dictionary references from legacy binary format
                LOWER_ENDPOINT_VALUE,   PVloopCurrentLowerEndPoint, loop_current_lower_endpoint_temp, loop_current_lower_endpoint_help_temp;
            }
        }

        VARIABLE loopCurrent
        {
//Remove new dictionary references from legacy binary format
            REDEFINE LABEL pv_loop_current_temp;
        }

        VARIABLE percentRange
        {
//Remove new dictionary references from legacy binary format
            REDEFINE LABEL pv_Percent_Range_temp;
        }

        VARIABLE upperRange_value
        {
//Remove new dictionary references from legacy binary format
            REDEFINE LABEL pv_upper_range_value_temp;
        }

        VARIABLE lowerRange_value
        {
//Remove new dictionary references from legacy binary format
            REDEFINE LABEL pv_lower_range_value_temp;
        }
    }
}

/*
 * Devices that support the Command 60 series
 */

/*****************************************************************************
 * PV Analog channel variables and collection
 */

VARIABLE PVloopUnits
{
//Remove new dictionary references from legacy binary format
    LABEL pv_loop_current_unit_temp;
//Remove new dictionary references from legacy binary format
    HELP  loop_current_unit_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 39, mA_temp }
    }
}

VARIABLE PVloopDamping
{
//Remove new dictionary references from legacy binary format
    LABEL pv_loop_current_damping_temp;
//Remove new dictionary references from legacy binary format
    HELP  loop_current_damping_help_temp;
    CLASS ANALOG_CHANNEL;
    CONSTANT_UNIT [sec];
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE  PVloopCurrentUpperEndPoint 
{
//Remove new dictionary references from legacy binary format
    LABEL pv_loop_current_upper_endpoint_temp;
//Remove new dictionary references from legacy binary format
    HELP loop_current_upper_endpoint_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE  PVloopCurrentLowerEndPoint 
{
//Remove new dictionary references from legacy binary format
    LABEL pv_loop_current_lower_endpoint_temp;
//Remove new dictionary references from legacy binary format
    HELP loop_current_lower_endpoint_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

/*****************************************************************************
 * SV Analog channel variables and collection
 */

VARIABLE SVanalogChannelValue
{
//Remove new dictionary references from legacy binary format
    LABEL sv_analog_value_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_value_help_temp;
    CLASS ANALOG_CHANNEL & DYNAMIC;
    HANDLING READ;
//Remove new dictionary references from legacy binary format
    CONSTANT_UNIT mA_temp;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE SVanalogChannelUnits
{
//Remove new dictionary references from legacy binary format
    LABEL sv_analog_unit_temp;
//Remove new dictionary references from legacy binary format
    HELP  analog_unit_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 39, mA_temp }
    }
}

VARIABLE SVanalogChannelDamping
{
//Remove new dictionary references from legacy binary format
    LABEL sv_analog_damping_temp;
//Remove new dictionary references from legacy binary format
    HELP  analog_damping_help_temp;
    CONSTANT_UNIT [sec];
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE  SVanalogChannelUpperEndPoint 
{
//Remove new dictionary references from legacy binary format
    LABEL sv_analog_upper_endpoint_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_upper_endpoint_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE  SVanalogChannelLowerEndPoint 
{
//Remove new dictionary references from legacy binary format
    LABEL sv_analog_lower_endpoint_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_lower_endpoint_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

COLLECTION OF VARIABLE SVanalog_io
{
//Remove new dictionary references from legacy binary format
    LABEL analog_input_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_input_block_help_temp;
    MEMBERS
    {
        /* Analog Information */
//Remove new dictionary references from legacy binary format
        ANALOG_VALUE,         SVanalogChannelValue,         analog_value_temp,                analog_value_help_temp;
//Remove new dictionary references from legacy binary format
        ANALOG_UNITS,         SVanalogChannelUnits,         analog_unit_temp,                 analog_unit_help_temp;
//Remove new dictionary references from legacy binary format
        ALARM_CODE,           SVanalogChannelAlarmCode,     loop_alarm_code_temp,             loop_alarm_code_help_temp;
//Remove new dictionary references from legacy binary format
        ANALOG_CHANNEL_FLAGS, SVanalogChannelFlags,         loop_flags_temp,                  loop_flags_help_temp;
//Remove new dictionary references from legacy binary format
        ANALOG_DAMPING,       SVanalogChannelDamping,       analog_damping_temp,              analog_damping_help_temp;
//Remove new dictionary references from legacy binary format
        UPPER_ENDPOINT_VALUE, SVanalogChannelUpperEndPoint, analog_upper_endpoint_temp,       analog_upper_endpoint_help_temp;
//Remove new dictionary references from legacy binary format
        LOWER_ENDPOINT_VALUE, SVanalogChannelLowerEndPoint, analog_lower_endpoint_temp,       analog_lower_endpoint_help_temp;
    }
}

/*****************************************************************************
 * Range/ scaling variables and collection
 */

VARIABLE SVpercentRange
{
//Remove new dictionary references from legacy binary format
    LABEL sv_percent_range_temp;
//Remove new dictionary references from legacy binary format
    HELP percent_of_range_help_temp;
    CLASS RANGE & DYNAMIC;
    HANDLING READ;
//Remove new dictionary references from legacy binary format
    CONSTANT_UNIT Percent_temp;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE SVupperRange_value
{
//Remove new dictionary references from legacy binary format
    LABEL sv_upper_range_value_temp;
//Remove new dictionary references from legacy binary format
    HELP upper_range_value_help_temp;
    CLASS RANGE;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE SVlowerRange_value
{
//Remove new dictionary references from legacy binary format
    LABEL sv_lower_range_value_temp;
//Remove new dictionary references from legacy binary format
    HELP lower_range_value_help_temp;
    CLASS RANGE;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

COLLECTION OF VARIABLE SVscaling
{
//Remove new dictionary references from legacy binary format
    LABEL analog_input_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_input_block_help_temp;
    MEMBERS
    {
        /* Range Information */
//Remove new dictionary references from legacy binary format
        PERCENT_RANGE,          SVpercentRange,                                         Percent_Range_temp,        percent_of_range_help_temp;
//Remove new dictionary references from legacy binary format
        TRANSFER_FUNCTION,      SVtransferFunction,                                     Transfer_Function_temp,    transfer_function_help_temp;
//Remove new dictionary references from legacy binary format
        UPPER_RANGE_VALUE,      SVupperRange_value,                                     Upper_Range_Value_temp,    upper_range_value_help_temp;
//Remove new dictionary references from legacy binary format
        LOWER_RANGE_VALUE,      SVlowerRange_value,                                     Lower_Range_Value_temp,    lower_range_value_help_temp;
//Remove new dictionary references from legacy binary format
        RANGE_UNITS,            deviceVariables[secondary_variable_code].CONFIG_UNITS,  range_unit_temp,           [range_units_help];
    }
}

/*****************************************************************************
 * TV Analog channel variables and collection
 */

VARIABLE TVanalogChannelValue
{
//Remove new dictionary references from legacy binary format
    LABEL tv_analog_value_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_value_help_temp;
    CLASS ANALOG_CHANNEL & DYNAMIC;
    HANDLING READ;
//Remove new dictionary references from legacy binary format
    CONSTANT_UNIT mA_temp;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE TVanalogChannelUnits
{
//Remove new dictionary references from legacy binary format
    LABEL tv_analog_unit_temp;
//Remove new dictionary references from legacy binary format
    HELP  analog_unit_help_temp;
    HANDLING READ;
    TYPE ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 39, mA_temp }
    }
}

VARIABLE TVanalogChannelDamping
{
//Remove new dictionary references from legacy binary format
    LABEL tv_analog_damping_temp;
//Remove new dictionary references from legacy binary format
    HELP  analog_damping_help_temp;
    CLASS ANALOG_CHANNEL;
    CONSTANT_UNIT [sec];
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE TVanalogChannelUpperEndPoint 
{
//Remove new dictionary references from legacy binary format
    LABEL tv_analog_upper_endpoint_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_upper_endpoint_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE TVanalogChannelLowerEndPoint 
{
//Remove new dictionary references from legacy binary format
    LABEL tv_analog_lower_endpoint_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_lower_endpoint_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

COLLECTION OF VARIABLE TVanalog_io
{
//Remove new dictionary references from legacy binary format
    LABEL analog_input_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_input_block_help_temp;
    MEMBERS
    {
        /* Analog Information */
//Remove new dictionary references from legacy binary format
        ANALOG_VALUE,         TVanalogChannelValue,         analog_value_temp,                analog_value_help_temp;
//Remove new dictionary references from legacy binary format
        ANALOG_UNITS,         TVanalogChannelUnits,         analog_unit_temp,                 analog_unit_help_temp;
//Remove new dictionary references from legacy binary format
        ALARM_CODE,           TVanalogChannelAlarmCode,     loop_alarm_code_temp,             loop_alarm_code_help_temp;
//Remove new dictionary references from legacy binary format
        ANALOG_CHANNEL_FLAGS, TVanalogChannelFlags,         loop_flags_temp,                  loop_flags_help_temp;
//Remove new dictionary references from legacy binary format
        ANALOG_DAMPING,       TVanalogChannelDamping,       analog_damping_temp,              analog_damping_help_temp;
//Remove new dictionary references from legacy binary format
        UPPER_ENDPOINT_VALUE, TVanalogChannelUpperEndPoint, analog_upper_endpoint_temp,       analog_upper_endpoint_help_temp;
//Remove new dictionary references from legacy binary format
        LOWER_ENDPOINT_VALUE, TVanalogChannelLowerEndPoint, analog_lower_endpoint_temp,       analog_lower_endpoint_help_temp;
    }
}

/*****************************************************************************
 * Range/ scaling variables and collection
 */

VARIABLE TVpercentRange
{
//Remove new dictionary references from legacy binary format
    LABEL tv_percent_range_temp;
//Remove new dictionary references from legacy binary format
    HELP percent_of_range_help_temp;
    CLASS RANGE & DYNAMIC;
    HANDLING READ;
//Remove new dictionary references from legacy binary format
    CONSTANT_UNIT Percent_temp;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE TVupperRange_value
{
//Remove new dictionary references from legacy binary format
    LABEL tv_upper_range_value_temp;
//Remove new dictionary references from legacy binary format
    HELP upper_range_value_help_temp;
    CLASS RANGE;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE TVlowerRange_value
{
//Remove new dictionary references from legacy binary format
    LABEL tv_lower_range_value_temp;
//Remove new dictionary references from legacy binary format
    HELP lower_range_value_help_temp;
    CLASS RANGE;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

COLLECTION OF VARIABLE TVscaling
{
//Remove new dictionary references from legacy binary format
    LABEL analog_input_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_input_block_help_temp;
    MEMBERS
    {
        /* Range Information */
//Remove new dictionary references from legacy binary format
        PERCENT_RANGE,          TVpercentRange,                                        Percent_Range_temp,        percent_of_range_help_temp;
//Remove new dictionary references from legacy binary format
        TRANSFER_FUNCTION,      TVtransferFunction,                                    Transfer_Function_temp,    transfer_function_help_temp;
//Remove new dictionary references from legacy binary format
        UPPER_RANGE_VALUE,      TVupperRange_value,                                    Upper_Range_Value_temp,    upper_range_value_help_temp;
//Remove new dictionary references from legacy binary format
        LOWER_RANGE_VALUE,      TVlowerRange_value,                                    Lower_Range_Value_temp,    lower_range_value_help_temp;
//Remove new dictionary references from legacy binary format
        RANGE_UNITS,            deviceVariables[tertiary_variable_code].CONFIG_UNITS,  range_unit_temp,           [range_units_help];
    }
}

/*****************************************************************************
 * QV Analog channel variables and collection
 */

VARIABLE QVanalogChannelValue
{
//Remove new dictionary references from legacy binary format
    LABEL qv_analog_value_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_value_help_temp;
    CLASS ANALOG_CHANNEL & DYNAMIC;
    HANDLING READ;
//Remove new dictionary references from legacy binary format
    CONSTANT_UNIT mA_temp;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE QVanalogChannelUnits
{
//Remove new dictionary references from legacy binary format
    LABEL qv_analog_unit_temp;
//Remove new dictionary references from legacy binary format
    HELP  analog_unit_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE ENUMERATED
    {
//Remove new dictionary references from legacy binary format
        { 39, mA_temp }
    }
}

VARIABLE QVanalogChannelDamping
{
//Remove new dictionary references from legacy binary format
    LABEL qv_analog_damping_temp;
//Remove new dictionary references from legacy binary format
    HELP  analog_damping_help_temp;
    CONSTANT_UNIT [sec];
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE QVanalogChannelUpperEndPoint 
{
//Remove new dictionary references from legacy binary format
    LABEL qv_analog_upper_endpoint_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_upper_endpoint_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE QVanalogChannelLowerEndPoint 
{
//Remove new dictionary references from legacy binary format
    LABEL qv_analog_lower_endpoint_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_lower_endpoint_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

COLLECTION OF VARIABLE QVanalog_io
{
//Remove new dictionary references from legacy binary format
    LABEL analog_input_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_input_block_help_temp;
    MEMBERS
    {
        /* Analog Information */
//Remove new dictionary references from legacy binary format
        ANALOG_VALUE,           QVanalogChannelValue,         analog_value_temp,                analog_value_help_temp;
//Remove new dictionary references from legacy binary format
        ANALOG_UNITS,           QVanalogChannelUnits,         analog_unit_temp,                 analog_unit_help_temp;
//Remove new dictionary references from legacy binary format
        ALARM_CODE,             QVanalogChannelAlarmCode,     loop_alarm_code_temp,             loop_alarm_code_help_temp;
//Remove new dictionary references from legacy binary format
        ANALOG_CHANNEL_FLAGS,   QVanalogChannelFlags,         loop_flags_temp,                  loop_flags_help_temp;
//Remove new dictionary references from legacy binary format
        ANALOG_DAMPING,         QVanalogChannelDamping,       analog_damping_temp,              analog_damping_help_temp;
//Remove new dictionary references from legacy binary format
        UPPER_ENDPOINT_VALUE,   QVanalogChannelUpperEndPoint, analog_upper_endpoint_temp,       analog_upper_endpoint_help_temp;
//Remove new dictionary references from legacy binary format
        LOWER_ENDPOINT_VALUE,   QVanalogChannelLowerEndPoint, analog_lower_endpoint_temp,       analog_lower_endpoint_help_temp;
    }
}

/*****************************************************************************
 * Range/ scaling variables and collection
 */

VARIABLE QVpercentRange
{
//Remove new dictionary references from legacy binary format
    LABEL qv_percent_range_temp;
//Remove new dictionary references from legacy binary format
    HELP percent_of_range_help_temp;
    CLASS RANGE & DYNAMIC;
    HANDLING READ;
//Remove new dictionary references from legacy binary format
    CONSTANT_UNIT Percent_temp;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE QVupperRange_value
{
//Remove new dictionary references from legacy binary format
    LABEL qv_upper_range_value_temp;
//Remove new dictionary references from legacy binary format
    HELP upper_range_value_help_temp;
    CLASS RANGE;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE QVlowerRange_value
{
//Remove new dictionary references from legacy binary format
    LABEL qv_lower_range_value_temp;
//Remove new dictionary references from legacy binary format
    HELP lower_range_value_help_temp;
    CLASS RANGE;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

COLLECTION OF VARIABLE QVscaling
{
//Remove new dictionary references from legacy binary format
    LABEL analog_input_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_input_block_help_temp;
    MEMBERS
    {
        /* Range Information */
//Remove new dictionary references from legacy binary format
        PERCENT_RANGE,          QVpercentRange,                                          Percent_Range_temp,        percent_of_range_help_temp;
//Remove new dictionary references from legacy binary format
        TRANSFER_FUNCTION,      QVtransferFunction,                                      Transfer_Function_temp,    transfer_function_help_temp;
//Remove new dictionary references from legacy binary format
        UPPER_RANGE_VALUE,      QVupperRange_value,                                      Upper_Range_Value_temp,    upper_range_value_help_temp;
//Remove new dictionary references from legacy binary format
        LOWER_RANGE_VALUE,      QVlowerRange_value,                                      Lower_Range_Value_temp,    lower_range_value_help_temp;
//Remove new dictionary references from legacy binary format
        RANGE_UNITS,            deviceVariables[quaternary_variable_code].CONFIG_UNITS,  range_unit_temp,           [range_units_help];
    }
}

/*
 * Relationships
 */

UNIT SVscaling_units_relation
{
    deviceVariables[secondary_variable_code].CONFIG_UNITS:
        SVupperRange_value,
        SVlowerRange_value
}

UNIT TVscaling_units_relation
{
    deviceVariables[tertiary_variable_code].CONFIG_UNITS:
        TVupperRange_value,
        TVlowerRange_value
}

UNIT QVscaling_units_relation
{
    deviceVariables[quaternary_variable_code].CONFIG_UNITS:
        QVupperRange_value,
        QVlowerRange_value
}

WRITE_AS_ONE SVscaling_wao
{
    SVupperRange_value,
    SVlowerRange_value
}

WRITE_AS_ONE TVscaling_wao
{
    TVupperRange_value,
    TVlowerRange_value
}

WRITE_AS_ONE QVscaling_wao
{
    QVupperRange_value,
    QVlowerRange_value
}

