/*****************************************************************************
 *
 * File:  PV2_4.ddl
 * Version: 2.4.0
 * Date: 01/14/2022
 *
 *****************************************************************************
 * Copyright (c) 2016-2022, FieldComm Group, All Rights Reserved
 *****************************************************************************
 *
 * Description: Defines the standard collections used by DDs that support
 *      more than one analog channel
 *
 *****************************************************************************
 */

/*****************************************************************************
 * The manufacturer line
 *****************************************************************************
 */
MANUFACTURER STANDARD, DEVICE_TYPE _PV, DEVICE_REVISION 2, DD_REVISION 4


/*****************************************************************************
 * Include Files
 *****************************************************************************
 */
#include "macros2.h"
#include "embedded_strings.h"
#include "methods.h"

/*****************************************************************************
 * Definitions (#define, typedef, enum)
 *****************************************************************************
 */
#ifdef _PDM_
IMPORT "PV2_3.ddl"
#else
IMPORT STANDARD _PV, DEVICE_REVISION 2, DD_REVISION 3
#endif
{
    EVERYTHING;

    REDEFINITIONS
    {
        /* TOKENIZER v8.2.20 seems to have a bug where ADDing members to a collection
           cause the collection to ONLY have those added members (the originals get
           forgotten). Tokenizer v10.44 works as expected.  Commented code below
           will not work in v8 tokenizer.  The work-around for now is to redefine the
           entire collection rather than just adding new members. */
        //COLLECTION OF VARIABLE analog_io
        //{
        //    MEMBERS
        //    {
//Remove new dictionary references from legacy binary format
        //        ADD UPPER_LIMIT_VALUE,    PVloopCurrentUpperLimit,    loop_current_upper_limit_temp,    loop_current_upper_limit_help_temp;
//Remove new dictionary references from legacy binary format
        //        ADD LOWER_LIMIT_VALUE,    PVloopCurrentLowerLimit,    loop_current_lower_limit_temp,    loop_current_lower_limit_help_temp;
        //    }
        //}

        COLLECTION OF VARIABLE analog_io
        {
            REDEFINE MEMBERS
            {
                //Original members
//Remove new dictionary references from legacy binary format
                ANALOG_VALUE,           loopCurrent,                  Loop_Current_temp,                loop_current_help_temp;
//Remove new dictionary references from legacy binary format
                ALARM_CODE,             loop_alarm_code,              loop_alarm_code_temp,             loop_alarm_code_help_temp;
//Remove new dictionary references from legacy binary format
                ANALOG_CHANNEL_FLAGS,   loop_flags,                   loop_flags_temp,                  loop_flags_help_temp;
//Remove new dictionary references from legacy binary format
                ANALOG_UNITS,           PVloopUnits,                  loop_current_unit_temp,           loop_current_unit_help_temp;
//Remove new dictionary references from legacy binary format
                ANALOG_DAMPING,         PVloopDamping,                loop_current_damping_temp,        loop_current_damping_help_temp;
//Remove new dictionary references from legacy binary format
                UPPER_ENDPOINT_VALUE,   PVloopCurrentUpperEndPoint,   loop_current_upper_endpoint_temp, loop_current_upper_endpoint_help_temp;
//Remove new dictionary references from legacy binary format
                LOWER_ENDPOINT_VALUE,   PVloopCurrentLowerEndPoint,   loop_current_lower_endpoint_temp, loop_current_lower_endpoint_help_temp;

                //New members to be added
//Remove new dictionary references from legacy binary format
                UPPER_LIMIT_VALUE,      PVloopCurrentUpperLimit,      loop_current_upper_limit_temp,    loop_current_upper_limit_help_temp;
//Remove new dictionary references from legacy binary format
                LOWER_LIMIT_VALUE,      PVloopCurrentLowerLimit,      loop_current_lower_limit_temp,    loop_current_lower_limit_help_temp;
            }
        }

        COLLECTION OF VARIABLE SVanalog_io
        {
            REDEFINE MEMBERS
            {
                //Original members
//Remove new dictionary references from legacy binary format
                ANALOG_VALUE,           SVanalogChannelValue,         analog_value_temp,                analog_value_help_temp;
//Remove new dictionary references from legacy binary format
                ANALOG_UNITS,           SVanalogChannelUnits,         analog_unit_temp,                 analog_unit_help_temp;
//Remove new dictionary references from legacy binary format
                ALARM_CODE,             SVanalogChannelAlarmCode,     loop_alarm_code_temp,             loop_alarm_code_help_temp;
//Remove new dictionary references from legacy binary format
                ANALOG_CHANNEL_FLAGS,   SVanalogChannelFlags,         loop_flags_temp,                  loop_flags_help_temp;
//Remove new dictionary references from legacy binary format
                ANALOG_DAMPING,         SVanalogChannelDamping,       analog_damping_temp,              analog_damping_help_temp;
//Remove new dictionary references from legacy binary format
                UPPER_ENDPOINT_VALUE,   SVanalogChannelUpperEndPoint, analog_upper_endpoint_temp,       analog_upper_endpoint_help_temp;
//Remove new dictionary references from legacy binary format
                LOWER_ENDPOINT_VALUE,   SVanalogChannelLowerEndPoint, analog_lower_endpoint_temp,       analog_lower_endpoint_help_temp;

                //New members to be added
//Remove new dictionary references from legacy binary format
                UPPER_LIMIT_VALUE,      SVanalogChannelUpperLimit,    Analog_Upper_Limit_temp,          analog_upper_limit_help_temp;
//Remove new dictionary references from legacy binary format
                LOWER_LIMIT_VALUE,      SVanalogChannelLowerLimit,    Analog_Lower_Limit_temp,          analog_lower_limit_help_temp;
            }
        }

        COLLECTION OF VARIABLE TVanalog_io
        {
            REDEFINE MEMBERS
            {
                //Original members
//Remove new dictionary references from legacy binary format
                ANALOG_VALUE,           TVanalogChannelValue,         analog_value_temp,                analog_value_help_temp;
//Remove new dictionary references from legacy binary format
                ANALOG_UNITS,           TVanalogChannelUnits,         analog_unit_temp,                 analog_unit_help_temp;
//Remove new dictionary references from legacy binary format
                ALARM_CODE,             TVanalogChannelAlarmCode,     loop_alarm_code_temp,             loop_alarm_code_help_temp;
//Remove new dictionary references from legacy binary format
                ANALOG_CHANNEL_FLAGS,   TVanalogChannelFlags,         loop_flags_temp,                  loop_flags_help_temp;
//Remove new dictionary references from legacy binary format
                ANALOG_DAMPING,         TVanalogChannelDamping,       analog_damping_temp,              analog_damping_help_temp;
//Remove new dictionary references from legacy binary format
                UPPER_ENDPOINT_VALUE,   TVanalogChannelUpperEndPoint, analog_upper_endpoint_temp,       analog_upper_endpoint_help_temp;
//Remove new dictionary references from legacy binary format
                LOWER_ENDPOINT_VALUE,   TVanalogChannelLowerEndPoint, analog_lower_endpoint_temp,       analog_lower_endpoint_help_temp;

                //New members to be added
//Remove new dictionary references from legacy binary format
                UPPER_LIMIT_VALUE,      TVanalogChannelUpperLimit,    Analog_Upper_Limit_temp,          analog_upper_limit_help_temp;
//Remove new dictionary references from legacy binary format
                LOWER_LIMIT_VALUE,      TVanalogChannelLowerLimit,    Analog_Lower_Limit_temp,          analog_lower_limit_help_temp;
            }
        }

        COLLECTION OF VARIABLE QVanalog_io
        {
            REDEFINE MEMBERS
            {
                //Original members
//Remove new dictionary references from legacy binary format
                ANALOG_VALUE,           QVanalogChannelValue,         analog_value_temp,                analog_value_help_temp;
//Remove new dictionary references from legacy binary format
                ANALOG_UNITS,           QVanalogChannelUnits,         analog_unit_temp,                 analog_unit_help_temp;
//Remove new dictionary references from legacy binary format
                ALARM_CODE,             QVanalogChannelAlarmCode,     loop_alarm_code_temp,             loop_alarm_code_help_temp;
//Remove new dictionary references from legacy binary format
                ANALOG_CHANNEL_FLAGS,   QVanalogChannelFlags,         loop_flags_temp,                  loop_flags_help_temp;
//Remove new dictionary references from legacy binary format
                ANALOG_DAMPING,         QVanalogChannelDamping,       analog_damping_temp,              analog_damping_help_temp;
//Remove new dictionary references from legacy binary format
                UPPER_ENDPOINT_VALUE,   QVanalogChannelUpperEndPoint, analog_upper_endpoint_temp,       analog_upper_endpoint_help_temp;
//Remove new dictionary references from legacy binary format
                LOWER_ENDPOINT_VALUE,   QVanalogChannelLowerEndPoint, analog_lower_endpoint_temp,       analog_lower_endpoint_help_temp;

                //New members to be added
//Remove new dictionary references from legacy binary format
                UPPER_LIMIT_VALUE,      QVanalogChannelUpperLimit,    Analog_Upper_Limit_temp,          analog_upper_limit_help_temp;
//Remove new dictionary references from legacy binary format
                LOWER_LIMIT_VALUE,      QVanalogChannelLowerLimit,    Analog_Lower_Limit_temp,          analog_lower_limit_help_temp;
            }
        }
    }
}

/*
 * Devices that support the Command 60 series
 */

/*****************************************************************************
 * Additional PV Analog channel variables
 */

VARIABLE  PVloopCurrentUpperLimit 
{
//Remove new dictionary references from legacy binary format
    LABEL pv_loop_current_upper_limit_temp;
//Remove new dictionary references from legacy binary format
    HELP loop_current_upper_limit_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE  PVloopCurrentLowerLimit 
{
//Remove new dictionary references from legacy binary format
    LABEL pv_loop_current_lower_limit_temp;
//Remove new dictionary references from legacy binary format
    HELP loop_current_lower_limit_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

/*****************************************************************************
 * Additional SV Analog channel variables
 */

VARIABLE  SVanalogChannelUpperLimit 
{
//Remove new dictionary references from legacy binary format
    LABEL sv_analog_upper_limit_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_upper_limit_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE  SVanalogChannelLowerLimit 
{
//Remove new dictionary references from legacy binary format
    LABEL sv_analog_lower_limit_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_lower_limit_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

/*****************************************************************************
 * Additional TV Analog channel variables
 */

VARIABLE TVanalogChannelUpperLimit 
{
//Remove new dictionary references from legacy binary format
    LABEL tv_analog_upper_limit_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_upper_limit_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE TVanalogChannelLowerLimit 
{
//Remove new dictionary references from legacy binary format
    LABEL tv_analog_lower_limit_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_lower_limit_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

/*****************************************************************************
 * Additional QV Analog channel variables
 */

VARIABLE QVanalogChannelUpperLimit 
{
//Remove new dictionary references from legacy binary format
    LABEL qv_analog_upper_limit_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_upper_limit_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE QVanalogChannelLowerLimit 
{
//Remove new dictionary references from legacy binary format
    LABEL qv_analog_lower_limit_temp;
//Remove new dictionary references from legacy binary format
    HELP analog_lower_limit_help_temp;
    CLASS ANALOG_CHANNEL;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}
